<h1 style="display: flex; align-items: center;">
  <img src="docs/assets/eunhaeng.jpeg" alt="Eunhaeng" style="height: 1em; vertical-align: middle; margin-right: 10px;">
  libeunhaeng
</h1>

- 국내 은행/카드사 거래내역 조회

![demo screenshot](docs/assets/demo-screenshot.png)

## 현재 지원 은행/카드사
- 신한은행
- 신한카드
- 현대카드
